@@ -1,8 +1,8 @@
-# Copyright (c) 2006 CentralNic Ltd. All rights reserved. This program is
+# Copyright (c) 2007 CentralNic Ltd. All rights reserved. This program is
 # free software; you can redistribute it and/or modify it under the same
 # terms as Perl itself.
 # 
-# $Id: Command.pm,v 1.3 2006/05/09 11:37:27 gavin Exp $
+# $Id: Command.pm,v 1.4 2007/12/03 11:44:51 gavin Exp $
 package Net::EPP::Frame::Command;
 use Net::EPP::Frame::Command::Check;
 use Net::EPP::Frame::Command::Create;
@@ -125,11 +125,11 @@ sub clTRID { $_[0]->getNode('clTRID') }
 
 =head1 AUTHOR
 
-Gavin Brown (L<epp@centralnic.com>) for CentralNic Ltd (http://www.centralnic.com/).
+CentralNic Ltd (http://www.centralnic.com/).
 
 =head1 COPYRIGHT
 
-This module is (c) 2006 CentralNic Ltd. This module is free software; you can
+This module is (c) 2007 CentralNic Ltd. This module is free software; you can
 redistribute it and/or modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
