@@ -1,8 +1,8 @@
-# Copyright (c) 2006 CentralNic Ltd. All rights reserved. This program is
+# Copyright (c) 2007 CentralNic Ltd. All rights reserved. This program is
 # free software; you can redistribute it and/or modify it under the same
 # terms as Perl itself.
 # 
-# $Id: Ack.pm,v 1.1 2006/12/13 13:54:17 gavin Exp $
+# $Id: Ack.pm,v 1.2 2007/12/03 11:44:52 gavin Exp $
 package Net::EPP::Frame::Command::Poll::Ack;
 use base qw(Net::EPP::Frame::Command::Poll);
 use strict;
@@ -52,11 +52,11 @@ sub setMsgID {
 
 =head1 AUTHOR
 
-Gavin Brown (L<epp@centralnic.com>) for CentralNic Ltd (http://www.centralnic.com/).
+CentralNic Ltd (http://www.centralnic.com/).
 
 =head1 COPYRIGHT
 
-This module is (c) 2006 CentralNic Ltd. This module is free software; you can
+This module is (c) 2007 CentralNic Ltd. This module is free software; you can
 redistribute it and/or modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
