@@ -1,9 +1,11 @@
-# Copyright (c) 2006 CentralNic Ltd. All rights reserved. This program is
+# Copyright (c) 2007 CentralNic Ltd. All rights reserved. This program is
 # free software; you can redistribute it and/or modify it under the same
 # terms as Perl itself.
 # 
-# $Id: Transfer.pm,v 1.2 2006/01/09 13:24:42 gavin Exp $
+# $Id: Transfer.pm,v 1.3 2007/12/03 11:44:52 gavin Exp $
 package Net::EPP::Frame::Command::Transfer;
+use Net::EPP::Frame::Command::Transfer::Contact;
+use Net::EPP::Frame::Command::Transfer::Domain;
 use base qw(Net::EPP::Frame::Command);
 use strict;
 
@@ -24,16 +26,22 @@ for the EPP C<E<lt>transferE<gt>> command.
 
 =head1 METHODS
 
-This module does not define any methods in addition to those it inherits from
-its ancestors.
+=cut
+
+sub setOp {
+	my ($self, $op) = @_;
+	$self->getCommandNode->setAttribute('op', $op);
+}
+
+=pod
 
 =head1 AUTHOR
 
-Gavin Brown (L<epp@centralnic.com>) for CentralNic Ltd (http://www.centralnic.com/).
+CentralNic Ltd (http://www.centralnic.com/).
 
 =head1 COPYRIGHT
 
-This module is (c) 2006 CentralNic Ltd. This module is free software; you can
+This module is (c) 2007 CentralNic Ltd. This module is free software; you can
 redistribute it and/or modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
